<?php
namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Request\Row;
use Teknisa\CRM\Service\crm00002006FilaContatoService;

class crm00002001OportunidadeDeNegocioEvolucaoController extends TeknisaCrud
{
    protected $dataSourceName = 'evolcont_crm_oportuni';
    protected $primaryKey = 'NRSEQEVOLCONT';
    //protected $CDCONTADOR = 'EVOLCONT';
    protected $environment;
    protected $connection;
    protected $filaContato;

    public function __construct($crudService, $parameterBag, $environment, EntityManager $entityManager, crm00002006FilaContatoService $filaContatoService, $util, $oportService) {
        parent::__construct($crudService, $parameterBag);
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
        $this->filaContatoService = $filaContatoService;
        $this->util = $util;
        $this->oportService = $oportService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $request = $this->util->modifyDateFilter($request, 'DTHREVOLCONT');
        
        parent::find($request, $response);
    }

    public function save(DTO\Request $request, DTO\Response $response) {
        try {
            foreach($request->getDataSet()->getRows() as $row) {
                $row["CDFILIAL"] = $this->environment->getCdFilial();
                if($row["__is_new"]) {
                    $row['__new_code_pk'] = "EVOLCONT";
                    $row['__table_pk'] = "NRSEQEVOLCONT";
                    $row['__cast_number'] = true;
                    $row['__new_code_length'] = 20;
                    $row['__columns_to_return'] = array("NRSEQEVOLCONT");
                }
            }
            
            parent::save($request, $response);
            if($row["__is_new"]) {
                $response->addDataset(new DataSet('DADOS', $this->crudService->getColumnsToReturn()));
            }
        }catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Atualiza a oportunidade de negócio no ato da evolução, com os campos Fase de Negociação e Operador Responsável.
     * 
     * @param DTO\Request\Row $request
     */
    public function atualizarOportunidade(DTO\Request\Row $request, DTO\Response $response, $entityManager = null) {
        $row = $request->getRow();
        
        $nrseqoport = $row["NRSEQOPORT"];
        $nrorg = is_null($this->environment->getNrOrg()) ? $row['NRORG'] : $this->environment->getNrOrg();
        $nrseqfasenego = isset($row["NRSEQFASENEGO"]) ? $row["NRSEQFASENEGO"] : null;
        $nrparcresp = isset($row["NRPARCRESP"]) ? $row["NRPARCRESP"] : null;
        $vroport = isset($row["VROPORT"]) ? $row["VROPORT"] : null;
        $vrprevoport = isset($row["VRPREVOPORT"]) ? $row["VRPREVOPORT"] : null;
        $nrtermoportuni = isset($row["NRTERMOPORTUNI"]) ? $row["NRTERMOPORTUNI"] : null;
        
        $params = array();
        
        $sql = "UPDATE CRM_OPORTUNI
                   SET ";
        if ($nrtermoportuni != null) {
            $sql .= " NRTERMOPORTUNI = :NRTERMOPORTUNI,";
            $params["NRTERMOPORTUNI"] = $nrtermoportuni;
        }
        
        if ($nrseqfasenego != null) {
            $sql .= " NRSEQFASENEGO = :NRSEQFASENEGO,";
            $params["NRSEQFASENEGO"] = $nrseqfasenego;
        }
        
        if ($nrparcresp != null) {
            $sql .= " NRPARCRESP = :NRPARCRESP,";
            $params["NRPARCRESP"] = $nrparcresp;
        }
        
        if ($vroport != null) {
            $sql .= " VROPORT = :VROPORT,";
            $params["VROPORT"] = $vroport;
        }
        
        if ($vrprevoport != null) {
            $sql .= " VRPREVOPORT = :VRPREVOPORT,";
            $params["VRPREVOPORT"] = $vrprevoport;
        }
        
        $params["NRSEQOPORT"] = $nrseqoport;
        $params["NRORG"] = $nrorg;
        
        $sql = substr($sql, 0, (strlen($sql)-1));
        $sql .= " WHERE NRSEQOPORT = :NRSEQOPORT
                    AND NRORG = :NRORG";
        
        if(!empty($entityManager)) {
            $this->connection = $entityManager->getConnection();
        }
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    /**
     * Insere uma tarefa no ato da evolução da oportunidade.
     * 
     * @param DTO\Request\Row $request
     */
    public function inserirTarefa(DTO\Request\Row $request, DTO\Response $response, $entityManager = null) {
        
        $row = $request->getRow();
        $nrorg = $this->environment->getNrOrg();
        $params = array(
            "DSFILACONTATO"         => $row["DSFILACONTATO"],
            "DTPLANFILACONTA"       => $row["DTPLANFILACONTA"],
            "CDOPERREAL"            => $row["CDOPERREAL"],
            "NRORG"                 => is_null($nrorg) ? $row['NRORG'] : $nrorg,
            "CDOPERINCLUSAO"        => $row["CDOPEREVOL"],
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRCONTATO"             => $row["NRSEQCONTATO"],
            "NRSEQCONTATO"          => $row["NRSEQCONTATO"],
            "NRSEQCLASSIFICATAREFA" => isset($row["NRSEQCLASSIFICATAREFA"]) ? $row["NRSEQCLASSIFICATAREFA"] : null,
            "NRPRIORFILACONT"       => isset($row["NRPRIORFILACONT"]) ? $row["NRPRIORFILACONT"] : 2,
            "NRSEQCAMPANHA"         => "",
            "NRSEQINTERLOCUTOR"     => empty($row['NRSEQINTERLOCUTOR']) ? '' : $row['NRSEQINTERLOCUTOR'],
            "DSEMAILTAREFA"         => empty($row['EMAILINTERLOC']) ? '' : $row['EMAILINTERLOC'],
            "DSTELEFONETAREFA"      => empty($row['NRTELEFONE1']) ? '' : $row['NRTELEFONE1'],
        );
        
        $nrseqfilaconta = $this->filaContatoService->inserirTarefa($params, $entityManager);
        
        $response->addDataset(new DataSet('DADOS', array("NRSEQFILACONTA" => $nrseqfilaconta)));
        
        return $nrseqfilaconta;
        
    }
    
    public function setTaskEndDate(Row $row) {
        
        $row = $row->getRow();
        
        $this->filaContatoService->callForSetTaskEndDate($row);
        
    }
    
    public function deactivateOpportunityTask(Row $row) {
        
        $row = $row->getRow();
        
        $this->filaContatoService->callForDeactivateOpportunityTask($row);
        
    }
    
    public function saveIntegracao(DTO\Request $request, DTO\Response $response, $entityManager = null) {
        $rows = $request->getDataSet()->getRows();
        foreach($rows as &$row) {
            $row["CDFILIAL"] = null;
            $row["NRRELACIONAPARC"] = null;
            if($row["__is_new"]) {
   		 		$row['__new_code_pk'] = "EVOLCONT";
	            $row['__table_pk'] = "NRSEQEVOLCONT";
	            $row['__cast_number'] = true;
	            $row['__new_code_length'] = 20;
                $row['__columns_to_return'] = array("NRSEQEVOLCONT");
                $row['__nrorgpadrao'] = $row['NRORG'];
            }
        }
        try {
            $datasource = new DataSet('EVOLUCAO', array($rows[0]));
            $request = new DTO\Request\DataSet($datasource, '', '', '');
            parent::save($request, $response);
            return $this->crudService->getColumnsToReturn();
        }catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function buscarOportunidade(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $oportunidade = $this->oportService->buscarOportunidade($row);
        
        $response->addDataset(new DataSet('DADOS', array("OPORTUNIDADE" => $oportunidade)));
    }
}
?>